StorageClass

Enum StorageClass 

pub enum StorageClass {
    MultiRegional,
    Regional,
    Nearline,
    Coldline,
    Standard,
    DurableReducedAvailability,
}
Variants



MultiRegional

Multi-Regional Storage is appropriate for storing data that is frequently accessed (“hot” objects), such as serving website content, interactive workloads, or data supporting mobile and gaming applications. Multi-Regional Storage data has the most availability compared to other storage classes.



Regional

Regional Storage enables you to store data at lower cost, with the trade-off of data being stored in a specific regional location, instead of having redundancy distributed over a large geographic area.



Nearline

Nearline Storage is a low-cost, highly durable storage service for storing infrequently accessed data. Nearline Storage is a better choice than Multi-Regional Storage or Regional Storage in scenarios where slightly lower availability, a 30-day minimum storage duration, and costs for data access are acceptable trade-offs for lowered storage costs.



Coldline

Coldline Storage is a very-low-cost, highly durable storage service for data archiving, online backup, and disaster recovery. Unlike other “cold” storage services, your data is available within milliseconds, not hours or days.



Standard

Users that create a bucket without specifying a default storage class see the bucket’s default storage class listed as Standard Storage in the API. Objects created without a storage class in such a bucket are also listed as Standard Storage in the API. Standard Storage is equivalent to Multi-Regional Storage when the associated bucket is located in a multi-regional location. Standard Storage is equivalent to Regional Storage when the associated bucket is located in a regional location.



DurableReducedAvailability

It is recommended that users utilize Regional Storage in place of Durable Reduced Availability (DRA). Regional Storage has lower pricing for operations, but otherwise the same price structure. Regional Storage also has better performance, particularly in terms of availability (DRA has a 99% availability SLA).