StandardQueryParameters

Struct StandardQueryParameters 

pub struct StandardQueryParameters<'a> {
    pub fields: Option<&'a str>,
    pub pretty_print: bool,
    pub quota_user: Option<&'a str>,
    pub user_ip: Option<&'a str>,
}
Standard Query Parameters can be used in almost any API request to GCS

Fields

fields: Option<&'a str>

Selector specifying a subset of fields to include in the response, the primary use of this is for better performance and lower response sizes. For more information, see the partial response documentation.

pretty_print: bool

Returns the response in a human-readable format, with indentations and line breaks, if true. Note that while the default value is true for GCP, this crate uses a default of false

quota_user: Option<&'a str>

Lets you enforce per-user quotas from a server-side application even in cases when the user’s IP address is unknown. This can occur, for example, with applications that run cron jobs on App Engine on a user’s behalf. You can choose any arbitrary string that uniquely identifies a user, but it is limited to 40 characters. Overrides userIp if both are provided. See more about Capping API usage

user_ip: Option<&'a str>

Lets you enforce per-user quotas when calling the API from a server-side application. See more about Capping API usage