pub struct DownloadObjectOptional<'a> {
pub standard_params: StandardQueryParameters<'a>,
pub generation: Option<i64>,
pub conditionals: Conditionals,
pub projection: Option<Projection>,
pub user_project: Option<&'a str>,
}Fields
standard_params: StandardQueryParameters<'a>generation: Option<i64>If present, selects a specific revision of this object (as opposed to the latest version, the default).
conditionals: Conditionalsprojection: Option<Projection>Set of properties to return. Defaults to noAcl, unless the object
resource specifies the acl property, when it defaults to full.
user_project: Option<&'a str>The project to be billed for this request. Required for Requester Pays buckets.