InsertObjectOptional

Struct InsertObjectOptional 

pub struct InsertObjectOptional<'a> {
    pub standard_params: StandardQueryParameters<'a>,
    pub content_type: Option<&'a str>,
    pub content_encoding: Option<&'a str>,
    pub conditionals: Conditionals,
    pub kms_key_name: Option<&'a str>,
    pub predefined_acl: Option<PredefinedAcl>,
    pub projection: Option<Projection>,
    pub user_project: Option<&'a str>,
}
Optional parameters when inserting an object. See here

Fields

standard_params: StandardQueryParameters<'a>content_type: Option<&'a str>

The Content-Type of the object, defaults to application/octet-stream.

content_encoding: Option<&'a str>

If set, sets the contentEncoding property of the final object to this value. Setting this parameter is equivalent to setting the contentEncoding metadata property. This can be useful when uploading an object with uploadType=media to indicate the encoding of the content being uploaded.

conditionals: Conditionalskms_key_name: Option<&'a str>

Resource name of the Cloud KMS key that will be used to encrypt the object. Overrides the object metadata’s kms_key_name value, if any.

predefined_acl: Option<PredefinedAcl>

Apply a predefined set of access controls to this object.

projection: Option<Projection>

Set of properties to return. Defaults to noAcl, unless the object resource specifies the acl property, when it defaults to full.

user_project: Option<&'a str>

The project to be billed for this request. Required for Requester Pays buckets.