pub struct RewriteObjectOptional<'a> {
pub standard_params: StandardQueryParameters<'a>,
pub destination_kms_key_name: Option<String>,
pub destination_predefined_acl: Option<String>,
pub destination_conditionals: Option<Conditionals>,
pub if_source_generation_match: Option<i64>,
pub if_source_generation_not_match: Option<i64>,
pub if_source_metageneration_match: Option<i64>,
pub if_source_metageneration_not_match: Option<i64>,
pub max_bytes_rewritten_per_call: Option<i64>,
pub projection: Option<Projection>,
pub source_generation: Option<i64>,
}Fields
standard_params: StandardQueryParameters<'a>destination_kms_key_name: Option<String>Resource name of the Cloud KMS key that will be used to encrypt the object. The Cloud KMS key must be located in same location as the object.
If the parameter is not specified, the method uses the destination bucket’s default encryption key, if any, or the Google-managed encryption key.
destination_predefined_acl: Option<String>Apply a predefined set of access controls to the destination object.
Acceptable values are:
- authenticatedRead: Object owner gets OWNER access, and allAuthenticatedUsers get READER access.
- bucketOwnerFullControl: Object owner gets OWNER access, and project team owners get OWNER access.
- bucketOwnerRead: Object owner gets OWNER access, and project team owners get READER access.
- private: Object owner gets OWNER access.
- projectPrivate: Object owner gets OWNER access, and project team members get access according to their roles.
- publicRead: Object owner gets OWNER access, and allUsers get READER access.
If iamConfiguration.uniformBucketLevelAccess.enabled is set to true, requests that include this parameter fail with a 400 Bad Request response.
destination_conditionals: Option<Conditionals>if_source_generation_match: Option<i64>Makes the operation conditional on whether the source object’s generation matches the given value.
if_source_generation_not_match: Option<i64>Makes the operation conditional on whether the source object’s generation does not match the given value.
if_source_metageneration_match: Option<i64>Makes the operation conditional on whether the source object’s current metageneration matches the given value.
if_source_metageneration_not_match: Option<i64>Makes the operation conditional on whether the source object’s current metageneration does not match the given value.
max_bytes_rewritten_per_call: Option<i64>The maximum number of bytes that will be rewritten per rewrite request. Most callers shouldn’t need to specify this parameter - it is primarily in place to support testing. If specified the value must be an integral multiple of 1 MiB (1048576). Also, this only applies to requests where the source and destination span locations and/or storage classes. Finally, this value must not change across rewrite calls else you’ll get an error that the rewriteToken is invalid.
projection: Option<Projection>Set of properties to return. Defaults to noAcl, unless the object
resource specifies the acl property, when it defaults to full.
source_generation: Option<i64>If present, selects a specific revision of the source object (as opposed to the latest version, the default).