pub struct ListOptional<'a> {
pub standard_params: StandardQueryParameters<'a>,
pub delimiter: Option<&'a str>,
pub include_trailing_delimiter: bool,
pub max_results: Option<u32>,
pub page_token: Option<&'a str>,
pub prefix: Option<&'a str>,
pub projection: Option<Projection>,
pub user_project: Option<&'a str>,
pub versions: bool,
}Fields
standard_params: StandardQueryParameters<'a>delimiter: Option<&'a str>Returns results in a directory-like mode. items will contain only objects whose names, aside from the prefix, do not contain delimiter. Objects whose names, aside from the prefix, contain delimiter will have their name, truncated after the delimiter, returned in prefixes. Duplicate prefixes are omitted.
include_trailing_delimiter: boolIf true, objects that end in exactly one instance of delimiter will have their metadata included in items in addition to prefixes.
max_results: Option<u32>Maximum number of items plus prefixes to return in a single page of responses. As duplicate prefixes are omitted, fewer total results may be returned than requested. The service will use this parameter or 1,000 items, whichever is smaller.
page_token: Option<&'a str>A previously-returned page token representing part of the larger set of results to view.
The pageToken is an encoded field that marks the name and generation of the last object in the returned list. In a subsequent request using the pageToken, items that come after the pageToken are shown (up to maxResults).
If you start a listing and then create an object in the bucket before using a pageToken to continue listing, you will not see the new object in subsequent listing results if it is in part of the object namespace already listed.
prefix: Option<&'a str>Filter results to objects whose names begin with this prefix.
projection: Option<Projection>user_project: Option<&'a str>The project to be billed for this request. Required for Requester Pays buckets.
versions: boolIf true, lists all versions of an object as distinct results. The default is false. For more information, see Object Versioning.